// Aggregator1.java
// Author: Stuart Clayman
// Email: sclayman@ee.ucl.ac.uk
// Date: July 2009

package eu.reservoir.aggregator.tests;

import eu.reservoir.aggregator.*;
import eu.reservoir.monitoring.core.ID;
import eu.reservoir.monitoring.core.DefaultProbeValue;
import java.util.Collection;
import java.util.HashSet;
import java.util.TreeSet;
import java.util.ArrayList;


/**
 * Test an Aggregator.
 * Uses the Aggregate support class.
 */
public class Aggregator1 {


    /**
     * Main test
     */
    public static void main(String[] args) {
	// Aggregation is average.
	AggregateFn fn = new AggregateFn() {
		public AggregatorMeasurement aggregate(Collection<ChooserResult> coll) {
		    // convert a Collection<ChooserResult> into Collection<Number>
		    ArrayList list = new ArrayList();
		    for (ChooserResult cr : coll) {
			list.add(((NumberCR)cr).number);
		    }

		    // aggregate the numbers
		    Aggregate aggregate = new Aggregate();
		    // to get the average
		    Number avg =  aggregate.average(list);

		    // now create a Measurement as the result

		    try {
			// field 0 is the avg
			DefaultProbeValue pv0 = new DefaultProbeValue(0, avg);
		    
			// create a list of ProbeValue
			ArrayList pvList = new ArrayList();
			pvList.add(pv0);

			// Construct the Measurement
			AggregatorMeasurement m = new AggregatorMeasurement(new ID(1456), "aggregated-average", pvList);

			// return it
			return m;
		    } catch (Exception e) {
			return null;
		    }
		    
		}
	    };

	// create a collection of numbers
	HashSet<ChooserResult> set = new HashSet<ChooserResult>();

	set.add( new NumberCR(11.1));	set.add( new NumberCR(12.2));
	set.add( new NumberCR(13.3));	set.add( new NumberCR(14.4));
	set.add( new NumberCR(15.5));	set.add( new NumberCR(16.6));
	set.add( new NumberCR(17.7));	set.add( new NumberCR(18.8));
	set.add( new NumberCR(19.9));


	// allocate an Aggregator
	Aggregator aggregator = new Aggregator();
	// set the aggregation function
	aggregator.setAggregateFn(fn);
	// and aggregate, gettign the average
	Object result = aggregator.aggregate(set);

	System.out.println("Aggregation = " + result);
    }

    static class NumberCR implements ChooserResult {
	public Number number;

	public NumberCR(Number n) {
	    number = n;
	}
    }

}